#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lifted-async
version:              0.10.2
visibility:           public
id:                   lifted-async-0.10.2-6xtC11ZmRn79QTvIIdcDMa
key:                  lifted-async-0.10.2-6xtC11ZmRn79QTvIIdcDMa
license:              BSD-3-Clause
copyright:            Copyright (C) 2012-2021 Mitsutoshi Aoe
maintainer:           Mitsutoshi Aoe <me@maoe.name>
author:               Mitsutoshi Aoe
homepage:             https://github.com/maoe/lifted-async
synopsis:
    Run lifted IO operations asynchronously and wait for their results

description:
    This package provides IO operations from @async@ package lifted to any
    instance of '\''MonadBase'\'' or '\''MonadBaseControl'\''.

category:             Concurrency
abi:                  d53f7896afec488e5fecf8148b1d9b60
exposed:              True
exposed-modules:
    Control.Concurrent.Async.Lifted
    Control.Concurrent.Async.Lifted.Safe

import-dirs:          /usr/lib/ghc-8.10.5/site-local/lifted-async-0.10.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/lifted-async-0.10.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/lifted-async-0.10.2
hs-libraries:         HSlifted-async-0.10.2-6xtC11ZmRn79QTvIIdcDMa
depends:
    async-2.2.3-EEZ7ScAbhsHIRG0TBpna8H base-4.14.2.0
    constraints-0.13-AnR9rNxGX5VB941qwyLpm4
    lifted-base-0.2.3.12-HsHHuUVdYcr6iiSvL0hwyv
    monad-control-1.0.2.3-Bi4GOATU8bxGtDgK1rR68J
    transformers-base-0.4.5.2-KzHjyAKDkdpHt6juu1Rjxn

haddock-interfaces:
    /usr/share/doc/haskell-lifted-async/html/lifted-async.haddock

haddock-html:         /usr/share/doc/haskell-lifted-async/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

